<?php

/**
 * Class Redq_WWC_Post_Type
 *
 * @author      redqteam
 * @category    Admin
 * @package     Wishlist\Admin
 * @version     1.0.0
 * @since       1.0.0
 */
class Redq_WWC_Post_Type {
  
  // public function __construct(){

  //   add_action( 'init', array( $this, 'register_post_type' ) );
      
  // }

  /**
   * Hook in methods.
   */
  public static function init() {
    add_action( 'init', array( __CLASS__, 'register_post_types' ), 5 );
    add_action( 'init', array( __CLASS__, 'register_post_status' ), 9 );
  }

  /**
   * Register core post types.
   */
  public static function register_post_types() {
    if ( post_type_exists('wwc_collection') ) {
      return;
    }

    do_action( 'redq_wwc_register_post_type' );

    register_post_type( 'wwc_collection',
      apply_filters( 'redq_wwc_register_post_type_collection',
        array(
          'labels' => array(
              'name'                  => __( 'Collections', 'wishlists-collections' ),
              'singular_name'         => __( 'Collection', 'wishlists-collections' ),
              'menu_name'             => _x( 'Collections', 'Admin menu name', 'wishlists-collections' ),
              'add_new'               => __( 'Add Collection', 'wishlists-collections' ),
              'add_new_item'          => __( 'Add New Collection', 'wishlists-collections' ),
              'edit'                  => __( 'Edit', 'wishlists-collections' ),
              'edit_item'             => __( 'Edit Collection', 'wishlists-collections' ),
              'new_item'              => __( 'New Collection', 'wishlists-collections' ),
              'view'                  => __( 'View Collection', 'wishlists-collections' ),
              'view_item'             => __( 'View Collection', 'wishlists-collections' ),
              'search_items'          => __( 'Search Collections', 'wishlists-collections' ),
              'not_found'             => __( 'No User Collections found', 'wishlists-collections' ),
              'not_found_in_trash'    => __( 'No User Collections found in trash', 'wishlists-collections' ),
              'parent'                => __( 'Parent Collection', 'wishlists-collections' ),
              'featured_image'        => __( 'Collection Image', 'wishlists-collections' ),
              'set_featured_image'    => __( 'Set Collection image', 'wishlists-collections' ),
              'remove_featured_image' => __( 'Remove Collection image', 'wishlists-collections' ),
              'use_featured_image'    => __( 'Use as Collection image', 'wishlists-collections' ),
          ),
          'description'         => __( 'This is where user can add new community blog to your site.', 'wishlists-collections' ),
          'public'              => true,
          'show_ui'             => true,
          'hierarchical'        => false, 
          'rewrite'             => true,
          'supports'            => array( 'title', 'editor' ),
          'has_archive'         => true,
          'show_in_nav_menus'   => true,
          'menu_icon'           => 'dashicons-groups',
        )
      )
    );
  }

  /**
   * Register our custom post statuses, used for collection status.
   */
  public static function register_post_status() {
    $collection_statuses = apply_filters( 'redq_wwc_register_collection_post_statuses',
      array(
        'shared'    => array(
          'label'                     => _x( 'Shared', 'wwc_collection', 'wwcb' ),
          'public'                    => true,
          'exclude_from_search'       => false,
          'show_in_admin_all_list'    => true,
          'show_in_admin_status_list' => true,
          'label_count'               => _n_noop( 'Shared <span class="count">(%s)</span>', 'Shared <span class="count">(%s)</span>', 'wwcb' )
        ),
      )
    );

    foreach ( $collection_statuses as $collection_status => $values ) {
      register_post_status( $collection_status, $values );
    }
  }

}

Redq_WWC_Post_Type::init();
