<?php

/**
 * Wishlist Collection & Bookmark  WWCB_Bookmarks
 *
 * Product bookmarkss class. Use the [bookmarks_button] shortcode inside the loop that will do the rest.
 * This post like also get anonymous like from any user who is not logged in to the site.
 * Anonymous post contains user's IP address.
 *
 * @class       WWCB_Bookmarks
 * @version     2.0.3
 * @package     Wishlists & Collections/Includes
 * @since       2.0.0
 * @category    Class
 * @author      redqteam
 */

class WWCB_Bookmarks {

  /**
   * __construct
   * Class constructor function contains product bookmarks ajax and the shortcode.
   *
   * @version 1.0.0
   * @since 1.0.0
   * @return null
   */
  public function __construct() {
    // add_action( 'wp_ajax_nopriv_add_to_bookmarks', array( $this, 'add_to_bookmarks' ) );
    add_action( 'wp_ajax_add_to_bookmarks', array( $this, 'add_to_bookmarks' ) );

    add_shortcode( 'wwc_bookmarks_button', array( $this, 'bookmarks_button_shortcode' ) );
  }

  /**
   * add_to_bookmarks
   * The main function for adding the post like.
   *
   * @version 1.0.0
   * @since 1.0.0
   * @return HTML
   */
  public function add_to_bookmarks() {
    $nonce = $_POST['nonce'];
      if ( ! wp_verify_nonce( $nonce, 'bookmarks' ) )
        die ( 'No Cheating!' );
      
      $post_id          = isset($_POST['post_id']) && $_POST['post_id'] != 'undefined' ? $_POST['post_id'] : 'null';
      $post_type        = isset($_POST['postType']) && $_POST['postType']!= 'undefined' ? $_POST['postType'] : 'null';
      $description      = isset($_POST['description']) && $_POST['description']!= 'undefined' ? $_POST['description'] : 'null';
      $current_user_id  = get_current_user_id();
      $bookmarked_posts = is_array(get_user_meta( $current_user_id, 'bookmarked_posts', true )) ? get_user_meta( $current_user_id, 'bookmarked_posts', true ) : [];
      if ($post_id != 'null' && $post_type != 'null') {
        if (isset($bookmarked_posts[$post_type])) {
          if (array_key_exists($post_id, $bookmarked_posts[$post_type])) {
        		unset($bookmarked_posts[$post_type][$post_id]);
          }else{
            $bookmarked_posts[$post_type][$post_id]['id'] = $post_id;
            $bookmarked_posts[$post_type][$post_id]['description'] = $description;
          }
        }else{
          $bookmarked_posts[$post_type][$post_id]['id'] = $post_id;
          $bookmarked_posts[$post_type][$post_id]['description'] = $description;
        }
        update_user_meta( $current_user_id, 'bookmarked_posts', $bookmarked_posts );
      }
  }


  /**
   * Generate the shortcode HTML link
   *
   * @param $post_id
   * @version 1.0.0
   * @since 1.0.0
   * @return HTML
   */
  public function get_product_add_to_bookmarks_link( $post_id, $icon, $icon_alt, $text_output ) {
    $post = get_post( $post_id );
    $post_type = $post->post_type;
    $current_user_id = get_current_user_id();
    $bookmarked = 'false';
    $bookmarked_posts = is_array(get_user_meta( $current_user_id, 'bookmarked_posts', true )) ? get_user_meta( $current_user_id, 'bookmarked_posts', true ) : [];
    if(isset($bookmarked_posts[$post_type])){
      if(array_key_exists($post_id, $bookmarked_posts[$post_type])){
        $bookmarked = 'true';
      }
    }
    $like_count = get_post_meta( $post_id, "_product_bookmarks_count", true ); // get post likes
    $count = ( empty( $like_count ) || $like_count == "0" ) ? 'Add to bookmarks' : esc_attr( $like_count );
    if ( $bookmarked === 'true' ) {
      $class = esc_attr( ' bookmarked' );
      $title = esc_attr( 'Remove from bookmarks' );
      $bookmarks = '<i class="redq-wwc-icon-bookmarks '.$icon.'"></i>';
      if( $text_output ) {
        $bookmarks .= esc_html__(' Bookmarked', 'wp-wishlist-collection');  
      }
      
      $output = '<a href="#" class="redq-wwc-add-bookmarks'.$class.'" data-post_id="'.$post_id.'" data-postType="'.$post_type.'" data-bookmarked="'.$bookmarked.'" title="'.$title.'">'.$bookmarks.'</a>';
    } else {
      $class = esc_attr( '' );
      $title = esc_attr( 'Add to bookmarks' );
      $bookmarks = '<i class="redq-wwc-icon-not-bookmarks '.$icon_alt.'"></i>';
      if( $text_output ) {
        $bookmarks .= esc_html__(' Bookmark', 'wp-wishlist-collection');  
      }
      $output = '<a href="#" class="redq-wwc-add-bookmarks'.$class.'" data-post_id="'.$post_id.'" data-postType="'.$post_type.'" data-bookmarked="'.$bookmarked.'" title="'.$title.'">'.$bookmarks.'</a>';
    }
    return $output;
  }

  /**
   * Add a shortcode to your product instead
   * type [bookmarks_button] in your product to output the button
   * @since 1.0.0
   * @return HTML
   */
  function bookmarks_button_shortcode( $atts, $content = null ) {
    extract( shortcode_atts( array(
      'id'          => get_the_ID(),
      'icon'        => 'ion-android-star',
      'icon_alt'    => 'ion-android-star-outline',
      'text_output' => 'true',
    ), $atts) );

    wp_localize_script( 'wwc-bookmarks', 'BOOKMARK_ICON', array(
      'icon'    => $icon,
      'iconAlt' => $icon_alt,
    ));
    return $this->get_product_add_to_bookmarks_link( $id, $icon, $icon_alt, $text_output );
  }

}

new WWCB_Bookmarks();
