<?php
/**
 * Wishlist & Collection  WWCB_BuddyPress
 *
 * @class       WWCB_BuddyPress
 * @version     2.1.0
 * @package     Wishlists & Collections/Includes
 * @since       2.1.0
 * @category    Class
 * @author      redqteam
 */

class WWCB_BuddyPress {

  public function __construct() {
    add_action( 'bp_setup_nav', array( $this,'wwcb_buddy_press_fav_func'), 99 ); 
    add_action( 'bp_template_content', array( $this, 'wwcb_all_fav_buddy_list_template') );
    add_action( 'bp_template_content', array( $this, 'wwcb_all_follower_buddy_list_template') );
    add_action( 'bp_before_member_header_meta', array( $this,'wwcb_user_fav_button_func') );
    add_action( 'wp_ajax_add_to_favbuddy', array( $this, 'add_to_favbuddy' ) );
    add_shortcode( 'wwcb_favbuddy', array( $this, 'wwcb_favbuddy_shortcode' ) );
  }

  // ************** FavBuddy Related Work ****************************

  public function add_to_favbuddy(){
    global $bp;
    $nonce = $_POST['nonce'];
    if ( ! wp_verify_nonce( $nonce, 'favbuddies' ) ) die ( 'Nonce Not verified!' );  
    if ( !empty( $_POST['action'] ) ) {
      $fav_buddy_id = $_POST['fav_user_id'];
      if ( function_exists ( 'wp_cache_post_change' ) ) {
        $GLOBALS["super_cache_enabled"] = 1;
        wp_cache_post_change( $fav_buddy_id );
      }
      if ( is_user_logged_in() ) {
        $user_id = get_current_user_id();
        $following_list = get_user_meta($user_id, '_wwcb_following', true);
        $follower_list = get_user_meta($fav_buddy_id, '_wwcb_follower', true);
        if ($following_list === '') {
          $following_list = array();
        }
        if ($follower_list === '') {
          $follower_list = array();
        }
        $following_control = $this->wwcb_buddy_control($following_list, $fav_buddy_id);
        update_user_meta($user_id, '_wwcb_following', $following_control);
        $follower_control = $this->wwcb_buddy_control($follower_list, $user_id);
        update_user_meta($fav_buddy_id, '_wwcb_follower', $follower_control);     
      }
    }
    exit;
  }


  public function wwcb_buddy_control($existing_arr = [], $incoming_id) {
    if (($key = array_search($incoming_id, $existing_arr)) !== false) {
      unset($existing_arr[$key]);
    } else {
      $existing_arr[] = (int) $incoming_id;
    }
    return $existing_arr;
  }


  public function allready_favListed($fav_user_id){
    if ( is_user_logged_in() ) { // user is logged in
      $current_user_id = get_current_user_id(); // current user
      $check_following_list = get_user_meta( $current_user_id, "_wwcb_following"); // user ids from post meta
      $FOLLOWED_USERS = ''; // set up array variable
      if ( count( $check_following_list ) != 0 ) { // meta exists, set up values
        $FOLLOWED_USERS = $check_following_list[0];
      }
      if( !is_array( $FOLLOWED_USERS ) ) {
        $FOLLOWED_USERS = array();
      }
      if ( in_array( $fav_user_id, $FOLLOWED_USERS ) ) {
        return true;
      } else {
        return false;
      }
    }
  }

  public function wwcb_user_add_to_favbuddy_link( $fav_user_id, $icon, $icon_alt, $text, $preview, $parent_class, $already_added ){
    global $bp;
    if( !empty( $already_added ) ) {
    	if( $already_added == 'true' ) {
    		$class = ' wished';
	      $title = esc_html__( 'Remove from BuddyList', 'wwcb' );
	      $heart = '<i class="redq-wwc-icon-wishlist '.$icon.'"></i>';
    	} else {
    		$class = '';
	      $title = esc_html__( 'Add to BuddyList', 'wwcb' );
	      $heart = '<i class="redq-wwc-icon-not-wishlist '.$icon_alt.'"></i>';
    	}
    } else {
    	if ( $this->allready_favListed( $fav_user_id ) ) {
	      $class = ' wished';
	      $title = esc_html__( 'Remove from BuddyList', 'wwcb' );
	      $heart = '<i class="redq-wwc-icon-wishlist '.$icon.'"></i>';
	    } else {
	      $class = '';
	      $title = esc_html__( 'Add to BuddyList', 'wwcb' );
	      $heart = '<i class="redq-wwc-icon-not-wishlist '.$icon_alt.'"></i>';
	    }
    }

    $class .= ' ' . $parent_class;

    $output = '';
    $output = '<div class="wwcb-buddy-sc-wrap">';
      $output .= '<a href="#" 
        class="redq-wwcb-favbuddy '.trim($class).'" 
        data-fav_user_id="'.$fav_user_id.'" 
        title="'.$title.'" 
        data-icon="'.$icon.'" 
        data-icon_alt="'.$icon_alt.'" 
        data-text="'.$text.'" 
        data-preview="'.$preview.'">';
        switch( $preview ) {
          case "text":
            $output .= esc_attr($text);
            break;
          case "icon":
            $output .= $heart;
            break;
          case "text_icon":
            $output .= esc_attr($text) . ' ' . $heart;
            break;
          case "icon_text":
            $output .= $heart . ' ' . esc_attr($text);
            break;
          default:
          $output .= esc_attr($text);
          break;
        }
      $output .= '</a>';
    $output .= '</div>';
    return $output;
  }

  public function wwcb_favbuddy_shortcode($atts, $content = null){
    global $bp;
    extract( shortcode_atts( array(
      'icon'          => 'ion-android-favorite',
      'icon_alt'      => 'ion-android-favorite-outline',
      'text'          => esc_html__('Follow', 'wwcb'),
      'preview'       => 'text_icon', // text, icon, text_icon, icon_text
      'parent_class'  => '',
      'fav_user_id'       => '',
      'already_added' => '',
    ), $atts) );
    if( $fav_user_id === '' ) {
      $fav_user_id = $bp->displayed_user->id;
    }
    $preview_mood = get_option('wwc_admin_settings', true);
    $preview = $preview_mood['favbuddy_button_preview'];
    $text = $preview_mood['wwcb_buddy_btn_text'];
    $icon = $preview_mood['wwcb_btn_icon'];
    $icon_alt = $preview_mood['wwcb_btn_icon_alt'];
    return $this->wwcb_user_add_to_favbuddy_link(
      $fav_user_id,
      $icon,
      $icon_alt,
      $text,
      $preview,
      $parent_class,
      $already_added
    );
  }


  // **************** BuddyPress Display Related Work *******************

  public function wwcb_user_fav_button_func(){
    global $bp;
    $current_user = get_current_user_id();
    $visit_buddy_id = $bp->displayed_user->id;
    $fav_buddy_shortcode = do_shortcode('[wwcb_favbuddy]');
    if ( $current_user !== $visit_buddy_id) {
      echo $fav_buddy_shortcode;
    }
  }

  public function wwcb_buddy_press_fav_func() { 
    global $bp;
    $following_args = array(
      'name' => esc_html__('FavBuddy', 'wwcb'),
      'slug' => 'wwcb-fav-buddy', 
      'default_subnav_slug' => 'wwcb-fav-buddy',
      'position' => 50, 
      'show_for_displayed_user' => true,
      'screen_function' => array( $this, 'wwcb_all_fav_buddy_list_func'),
      'item_css_id' => 'wwcb-fav-buddy',
    );
    bp_core_new_nav_item($following_args);
  }

  public function wwcb_all_fav_buddy_list_func() {
    bp_core_load_template( 
      apply_filters( 'bp_core_template_plugin', 'members/single/plugins' ) 
    );
  }

  public function wwcb_all_fav_buddy_list_template() {
    $file = '';
    $file = 'wishlist-buddypress-following-list.php';
    return require_once WWCB_TEMPLATE_PATH.$file;
  }

  public function wwcb_all_follower_buddy_list_template(){
    $file = '';
    $file = 'wishlist-buddypress-follower-list.php';
    return require_once WWCB_TEMPLATE_PATH.$file;    
  }    

}

/**
 * Wishlist & Collection  WWCB_BuddyPress 
 *
 * WWCB_BuddyPress Class check if it's active or not.
 */
$wwc_admin_settings = '';
$wwc_admin_settings = get_option('wwc_admin_settings', true);
if( class_exists('BuddyPress') ) {
  if( $wwc_admin_settings['enable_wishlist_on_bp'] !== 'no' ) {
    new WWCB_BuddyPress();
  }
}