<?php 

/**
 * Wishlist & Collection  Redq_Wishlist_Collection_Collections
 *
 * Post like class. Use the [collection_button] shortcode inside the loop that will do the rest.
 * This post like also get anonymous like from any user who is not logged in to the site.
 * Anonymous post contains user's IP address.
 *
 * @class       Redq_Wishlist_Collection_Collections
 * @version     2.0.3
 * @package     Wishlist & Collection/Includes
 * @since       1.0.0
 * @category    Class
 * @author      redqteam
 */

class Redq_Wishlist_Collection_Collections {

	/**
	 * __construct
	 * Class constructor function contains product wishlist ajax and the shortcode.
	 *
	 * @version 1.0.0
	 * @since 1.0.0
	 * @return null
	 */
	public function __construct() {
		// add_action( 'wp_ajax_nopriv_add_to_collection', array($this, 'add_to_collection') );
		add_action( 'wp_ajax_add_to_collection', array($this, 'add_to_collection') );
		
		add_shortcode( 'wwc_collection_button', array( $this, 'collection_button_shortcode' ) );
		
		add_action( 'wp_ajax_get_collections', array($this, 'get_collections') );
		add_action( 'wp_ajax_set_collections', array($this, 'set_collections') );
		add_action( 'wp_ajax_get_collection', array($this, 'get_collection') );
		add_action( 'wp_ajax_update_collection', array($this, 'update_collection') );
		add_action( 'wp_ajax_add_new_collection', array($this, 'add_new_collection') );
		add_action( 'wp_ajax_get_shared', array($this, 'get_shared') );
		add_action( 'wp_ajax_set_shared', array($this, 'set_shared') );

	}
	/**
	 * get_collections
	 * get all collection lists
	 *
	 * @version 2.0.3
	 * @since 1.0.0
	 * @return JSON
	 */
	public function get_collections() {
		
		$args = array(
			'post_type'       => 'wwc_collection',
			'author'          => get_current_user_id(),
			'post_status'     => array('publish', 'private', 'shared'),
			'posts_per_page'  => -1,
			'meta_key'        => 'post_type',
			'meta_value'      => $_POST['post_type'],
		);

		$collections = get_posts( $args );
		
		foreach ($collections as $index => $collection) {
			$collection_lists = array_reverse(get_post_meta($collection->ID, '_collection_products', true));

			$temp_collection = array();
			foreach ($collection_lists as $key => $list) {
				
				$check_post = get_post($list['pid']);
				$check_post_image = get_post($list['purl_id']);

				if( !empty( $check_post ) && $check_post->post_status != 'trash' && !empty( $check_post_image ) ) {
					// $temp_collection[] = $list;
					$collection_lists[$key]['purl_id'] = wp_get_attachment_url( $list['purl_id'] );
				}
			}

			
			// _log($temp_collection);
			$collections[$index]->meta = $collection_lists;
		}
		
		$datas= array(
			'collections'           => $collections,
			'product_collections'   => get_post_meta( $_POST['product_id'], "_product_collections", true ),
		);
		
		echo json_encode( $datas );

		wp_die();
	}
	public function get_collection($post_id) {
		echo json_encode(wp_get_single_post($_POST['post_id']));
		wp_die();
	}
	public function add_new_collection() {

		switch ($_POST['privacy']) {
			case 'public':
				$post_status = 'publish';
			break;
			
			default:
				$post_status = $_POST['privacy'];
			break;
		}
		
		$postarr = array(
			'post_author'   => get_current_user_id(),
			'post_content'  => $_POST['desc'],
			'post_title'    => $_POST['collectionName'],
			'post_status'   => $post_status,
			'post_type'     => 'wwc_collection',
		);
		$post_id = wp_insert_post($postarr);

		update_post_meta($post_id, 'post_type', $_POST['postType']);
		echo $post_id;
		// update_post_meta( $val, '_collection_privacy', $_POST['privacy']);

		wp_die();
	}
	public function update_collection() {
		$post_update                  = array();
		$post_update['ID']            = $_POST['post_id'];
		$post_update['post_title']    = $_POST['title'];
		$post_update['post_content']  = $_POST['desc'];
		$post_update['post_status']   = $_POST['post_status'];

		echo wp_update_post( $post_update );
		wp_die();
	}
	function check_exists($array, $key, $val) {
			foreach ($array as $item)
					if (isset($item[$key]) && $item[$key] == $val)
							return true;
			return false;
	}

	function check_exists_index($array, $key, $val) {
			foreach ($array as $index => $item)
					if (isset($item[$key]) && $item[$key] == $val)
							return $index;
			return '';
	}
	
	public function set_collections () {
		$productId            = $_POST['productId'];
		$productImgUrlId        = $_POST['productImgUrl'];
		$productPostType        = $_POST['postType'];
		$checkedCollection    = (isset( $_POST['checkedCollection'] ) ) ? $_POST['checkedCollection'] : array();
		$uncheckedCollection  = ( isset( $_POST['uncheckedCollection'] ) ) ? $_POST['uncheckedCollection'] : array();
		$product_collections  = null;

		if( !empty( $checkedCollection ) ) {
			foreach ($checkedCollection as $checked) {
				$collection_products = get_post_meta( $checked, '_collection_products', true );

				if( empty( $collection_products ) ) {
					$collection_products = array();
				}
				
				if( !empty( $collection_products ) ) {
					if( !$this->check_exists( $collection_products, 'pid', $productId ) ) {
						$collection_products[] = array( 
							'pid' => $productId,
							'purl_id' => $productImgUrlId,
							'pPostType' => $productPostType
						);
					}
				} else {
					$collection_products[] = array( 
						'pid' => $productId,
						'purl_id' => $productImgUrlId,
						'pPostType' => $productPostType
					);
				}

				update_post_meta( $checked, '_collection_products', $collection_products);

				$product_collections = get_post_meta( $productId, '_product_collections', true );

				if( empty( $product_collections ) ) {
					$product_collections = array();
				}
				
				if( !in_array($checked, $product_collections) ) {
					$product_collections[] = $checked;
				}

				update_post_meta( $productId, '_product_collections', $product_collections);
			}
		}
		
		if( !empty( $uncheckedCollection ) ) {

			foreach ($uncheckedCollection as $unchecked) {
				$hold = array();
				$collection_products = get_post_meta( $unchecked, '_collection_products', true );
				$product_collections = get_post_meta( $productId, '_product_collections', true );
				// _log($product_collections);
				if( in_array($unchecked, $product_collections) ) {
					$pid_key = array_search( $unchecked, $product_collections ); // find the key
					unset($product_collections[$pid_key] ); // remove from array
					update_post_meta( $productId, '_product_collections', $product_collections);
				}

				foreach ($collection_products as $elm => $collection_product) {
						if( $collection_product['pid'] == $productId ) {
							array_splice($collection_products, $elm, 1);

							update_post_meta( $unchecked, '_collection_products', $collection_products);
						}
				}
				
			}
		}

		$product_collections = get_post_meta( $productId, '_product_collections', true );

		echo json_encode( array( 'count' => count($product_collections), 'id' => '#redq-wishlist-'.$productId ) );

		wp_die();
	}
	public function get_shared($post_id) {
		$val = get_post_meta($_POST['post_id'],'_collection_shared')[0];
		echo $val;
		wp_die();
	}
	public function set_shared($post_id, $values) {
		update_post_meta($_POST['post_id'], '_collection_shared', $_POST['values']);
		wp_die();
	}
	/**
	 * add_to_collection
	 * The main function for adding the post like.
	 *
	 * @version 1.0.0
	 * @since 1.0.0
	 * @return HTML
	 */
	public function add_to_collection() {
		// global $wpdb;
		// $tablename = $wpdb->base_prefix . "up_activity";
		// $current_blog_id = get_current_blog_id();
		$nonce = $_POST['nonce'];
			if ( ! wp_verify_nonce( $nonce, 'wishlists' ) )
					die ( 'Nope!' );

		if ( isset( $_POST['add_to_wishlist'] ) ) {

			$post_id = $_POST['post_id']; // post id
			$post_like_count = get_post_meta( $post_id, "_product_wishlist_count", true ); // post like count

			if ( function_exists ( 'wp_cache_post_change' ) ) { // invalidate WP Super Cache if exists
				$GLOBALS["super_cache_enabled"] = 1;
				wp_cache_post_change( $post_id );
			}

			if ( is_user_logged_in() ) { // user is logged in
				$user_id      = get_current_user_id(); // current user
				$meta_POSTS   = get_user_option( "_wishlisted_product", $user_id  ); // post ids from user meta
				$meta_USERS   = get_post_meta( $post_id, "_user_wished" ); // user ids from post meta
				$liked_POSTS  = NULL; // setup array variable
				$liked_USERS  = NULL; // setup array variable
				$post_author  = get_post_field( 'post_author', $post_id );

				if ( count( $meta_POSTS ) != 0 ) { // meta exists, set up values
					$liked_POSTS = $meta_POSTS;
				}

				if ( !is_array( $liked_POSTS ) ) // make array just in case
					$liked_POSTS = array();

				if ( count( $meta_USERS ) != 0 ) { // meta exists, set up values
					$liked_USERS = $meta_USERS[0];
				}

				if ( !is_array( $liked_USERS ) ) // make array just in case
					$liked_USERS = array();

				$liked_POSTS['product-'.$post_id] = $post_id; // Add post id to user meta array
				$liked_USERS['user-'.$user_id] = $user_id; // add user id to post meta array
				$user_likes = count( $liked_POSTS ); // count user likes

				if ( !$this->already_added( $post_id ) ) { // like the post
					update_post_meta( $post_id, "_user_wished", $liked_USERS ); // Add user ID to post meta
					update_post_meta( $post_id, "_product_wishlist_count", ++$post_like_count ); // +1 count post meta
					update_user_option( $user_id, "_wishlisted_product", $liked_POSTS ); // Add post ID to user meta
					update_user_option( $user_id, "_user_wishlist_count", $user_likes ); // +1 count user meta
					echo $post_like_count; // update count on front end

				} else { // unlike the post
					$pid_key = array_search( $post_id, $liked_POSTS ); // find the key
					$uid_key = array_search( $user_id, $liked_USERS ); // find the key
					unset( $liked_POSTS[$pid_key] ); // remove from array
					unset( $liked_USERS[$uid_key] ); // remove from array
					$user_likes = count( $liked_POSTS ); // recount user likes
					update_post_meta( $post_id, "_user_wished", $liked_USERS ); // Remove user ID from post meta
					update_post_meta($post_id, "_product_wishlist_count", --$post_like_count ); // -1 count post meta
					update_user_option( $user_id, "_wishlisted_product", $liked_POSTS ); // Remove post ID from user meta
					update_user_option( $user_id, "_user_wishlist_count", $user_likes ); // -1 count user meta
					echo "already".$post_like_count; // update count on front end

				}

			} else { // user is not logged in (anonymous)
				$ip = $_SERVER['REMOTE_ADDR']; // user IP address
				$meta_IPS = get_post_meta( $post_id, "_user_IP" ); // stored IP addresses
				$liked_IPS = NULL; // set up array variable

				if ( count( $meta_IPS ) != 0 ) { // meta exists, set up values
					$liked_IPS = $meta_IPS[0];
				}

				if ( !is_array( $liked_IPS ) ) // make array just in case
					$liked_IPS = array();

				if ( !in_array( $ip, $liked_IPS ) ) // if IP not in array
					$liked_IPS['ip-'.$ip] = $ip; // add IP to array

				if ( !$this->already_added( $post_id ) ) { // like the post
					update_post_meta( $post_id, "_user_IP", $liked_IPS ); // Add user IP to post meta
					update_post_meta( $post_id, "_product_wishlist_count", ++$post_like_count ); // +1 count post meta
					echo $post_like_count; // update count on front end

				} else { // unlike the post
					$ip_key = array_search( $ip, $liked_IPS ); // find the key
					unset( $liked_IPS[$ip_key] ); // remove from array
					update_post_meta( $post_id, "_user_IP", $liked_IPS ); // Remove user IP from post meta
					update_post_meta( $post_id, "_product_wishlist_count", --$post_like_count ); // -1 count post meta
					echo "already".$post_like_count; // update count on front end

				}
			}
		}

		exit;
	}
	/**
	 * Generate the shortcode HTML link
	 *
	 * @param $post_id
	 * @version 2.0.3
	 * @since 1.0.0
	 * @return HTML
	 */
	public function get_post_add_to_wishlist_link( $post_id ) {
		global $post;
		$tittle = get_the_title($post_id );
		$feat_image_src = wp_get_attachment_image_src( get_post_thumbnail_id(), 'thumbnail' );
		
		if( !empty( $feat_image_src[0] ) ) {
			$feat_image_url = $feat_image_src[0];
		} else {
			$feat_image_url = WWCB_IMG . 'collections-placeholder.png';
		}

		$product_collections = get_post_meta($post_id, '_product_collections', true);
		$user_id = get_current_user_id();
		$args = array(
			'post_type'       => 'wwc_collection',
			'post_author'     => $user_id,
			'post_status'     => array('publish', 'private', 'shared'),
			'posts_per_page'  => -1,
		);

		$collections = get_posts( $args );
		// var_dump($product_collections);
		$icon_class = 'ion-ios-albums-outline';
		foreach ($collections as $collection) {
			
			if( is_user_logged_in() && is_array( $product_collections ) && in_array($collection->ID, $product_collections) && $collection->post_author == get_current_user_id() ) {
				$icon_class = 'ion-ios-albums';
			}
		}
		global $post;
		return "<a href='#' class='redq-wwc-add-collection' data-post_type='".$post->post_type."' data-post_id='".$post_id."' data-tittle='".$tittle."' data-image_id='".get_post_thumbnail_id()."' title='Add to collection'><i class='".'wwc-icon-pos '.$icon_class."'></i><div id='redq-wishlist-$post_id' class='redq-wwc-collection-dom'></div></a>";
	}

	/**
	 * Add a shortcode to your product instead
	 * type [collection_button] in your product to output the button
	 * @since 1.0.0
	 * @return HTML
	 */
	function collection_button_shortcode() {
		return $this->get_post_add_to_wishlist_link( get_the_ID() );
	}

}

new Redq_Wishlist_Collection_Collections();
