<?php

/**
 * Class WWCB_Frontend_Scripts
 *
 * @author      redqteam
 * @category    Admin
 * @package     Wishlist\Includes
 * @version     1.0.0
 * @since       1.0.0
 */
class WWCB_Frontend_Scripts {

	protected $custom_scripts = array(
		'wishlist_frontend',
		'vendor'
	);

  /**
   *  @hook wp_enqueue_scripts
   */
  public function __construct() {
    add_action('wp_enqueue_scripts' , array( $this , 'load_all_styles' ));
    add_action('wp_enqueue_scripts' , array( $this , 'load_all_scripts' ));
  }

  /**
   * Load all styles
   */
  public function load_all_styles() {
    wp_register_style( 'ionicons', '//code.ionicframework.com/ionicons/2.0.1/css/ionicons.min.css', array(), false, 'all' );
    wp_enqueue_style( 'ionicons' );

    wp_register_style( 'qtip2', '//cdn.jsdelivr.net/qtip2/3.0.3/jquery.qtip.min.css', array(), false, 'all' );
    wp_enqueue_style( 'qtip2' );

    wp_register_style( 'sweetalert2', '//cdn.jsdelivr.net/sweetalert2/6.2.4/sweetalert2.min.css', array(), false, 'all' );
    wp_enqueue_style( 'sweetalert2' );

    wp_register_style( 'wishlist-collection', WWCB_CSS . 'style.css', array(), false, 'all' );
    wp_enqueue_style( 'wishlist-collection' );

    wp_register_style( 'magnific-popup', WWCB_CSS . 'magnific-popup.css', array(), false, 'all' );
    wp_enqueue_style( 'magnific-popup' );

    wp_register_style( 'wishlist-select', WWCB_CSS . 'react-select.min.css', array(), false, 'all' );
    wp_enqueue_style( 'wishlist-select' );

    wp_register_style( 'wishlist-buddypress', WWCB_CSS_VEN . 'wwcb-buddypress-support.css', array(), false, 'all' );
    wp_enqueue_style( 'wishlist-buddypress' );    


  }

  /**
   * Load all scripts
   */
  public function load_all_scripts() {

    $is_login = false;
    if( is_user_logged_in() ) {
      $is_login = true;
    }

    $wwc_admin_settings = get_option('wwc_admin_settings', true);
    wp_register_script( 'wishlist-react', WWCB_VENDOR_JS.'react.min.js', array(), $ver = false, true);
    wp_enqueue_script( 'wishlist-react' );
    wp_register_script( 'wishlist-react-dom', WWCB_VENDOR_JS.'react-dom.min.js', array(), $ver = false, true
    );
    wp_enqueue_script( 'wishlist-react-dom' );
    wp_register_script( 'qtip2', '//cdnjs.cloudflare.com/ajax/libs/qtip2/3.0.3/jquery.qtip.min.js', array('jquery'), false, true );
    wp_enqueue_script( 'qtip2');

    wp_register_script( 'sweetalert2', '//cdn.jsdelivr.net/sweetalert2/6.2.4/sweetalert2.min.js', array('jquery'), false, true );
    wp_enqueue_script( 'sweetalert2');

    wp_register_script( 'wwc-wishlist', WWCB_VENDOR_JS.'wishlist.js', array('jquery'), false, true );
    wp_enqueue_script( 'wwc-wishlist');

    wp_localize_script( 'wwc-wishlist', 'WISHLIST', array(
      'nonce' => wp_create_nonce( 'wishlists' ),
      'ajaxurl' => admin_url('admin-ajax.php'),
      'LANG' => Redq_WWC_Localization::js_language_input(),
      'isLogin' => $is_login,
      'myAccount' => esc_url( get_permalink( $wwc_admin_settings['login_page_url'] ) ),
    ));


    wp_register_script( 'wwc-favbuddy', WWCB_VENDOR_JS.'wwcbFavBuddy.js', array('jquery'), false, true );
    wp_enqueue_script( 'wwc-favbuddy');

    wp_localize_script( 'wwc-favbuddy', 'FAVBUDDY', array(
      'nonce' => wp_create_nonce( 'favbuddies' ),
      'ajaxurl' => admin_url('admin-ajax.php'),
      'LANG' => Redq_WWC_Localization::js_language_input(),
      'isLogin' => $is_login,
      'myAccount' => esc_url( get_permalink( $wwc_admin_settings['login_page_url'] ) ),
    ));


    // wp_localize_script( 'wwc-wishlist', 'WISHLIST_ICON', array(
    //   'icon'    => apply_filters( 'redq_wishlist_icon',  'fa fa-heart' ),
    //   'iconAlt' => apply_filters( 'redq_wishlist_icon_alt',  'fa fa-heart-o' ),
    //   // 'text'    => 'Favorite',
    //   // 'preview' => 'icon_text',
    // ) );

    wp_register_script( 'magnific-popup', WWCB_VENDOR_JS.'jquery.magnific-popup.min.js', array('jquery'), false, true );
    wp_enqueue_script( 'magnific-popup');

    wp_register_script( 'wwc-bookmarks', WWCB_VENDOR_JS.'bookmarks.js', array('jquery', 'magnific-popup'), false, true );
    wp_enqueue_script( 'wwc-bookmarks');

    wp_localize_script( 'wwc-bookmarks', 'BOOKMARKS', array(
      'nonce' => wp_create_nonce( 'bookmarks' ),
      'ajaxurl' => admin_url('admin-ajax.php'),
      'LANG' => Redq_WWC_Localization::js_language_input(),
      'isLogin' => $is_login,
      'myAccount' => esc_url( get_permalink( $wwc_admin_settings['login_page_url'] ) ),
    ));

    $this->load_reuse_form_scripts();



		$frontend_scripts = json_decode(file_get_contents( WWCB_FILE . "/resource/frontend-assets.json"),true);
		foreach ($frontend_scripts as $filename => $file) {
			if (in_array($filename, $this->custom_scripts)) {
				wp_register_script( $filename, WWCB_JS. $file['js'] , array('jquery'), false, true);
				wp_enqueue_script( $filename );
			}
	    wp_localize_script( $filename, 'COLLECTION', array(
	      'nonce' => wp_create_nonce( 'collections' ),
	      'ajaxurl' => admin_url('admin-ajax.php'),
	      'placeholder_image' => WWCB_IMG . 'collections-placeholder.png',
	      'LANG' => Redq_WWC_Localization::js_language_input(),
	      'allUsers' => redq_wwc_get_all_user_info(),
	      'isLogin' => $is_login,
	      'myAccount' => esc_url( get_permalink( $wwc_admin_settings['login_page_url'] ) ),
	    ));
		}
  
  }

  public function load_reuse_form_scripts() {
    if ( !is_plugin_active( 'redq-reuse-form/redq-reuse-form.php' ) ) {
      wp_register_script( 'reuse-form-variable', WWCB_VENDOR_JS.'reuse-form-variable.js', array(), $ver = true, true);
      wp_enqueue_script( 'reuse-form-variable' );
      wp_register_style('reuse-form-two', WWCB_CSS.'reuse-form-two.css', array(), $ver = false, $media = 'all');
      wp_enqueue_style('reuse-form-two');
      wp_register_style('reuse-form', WWCB_CSS.'reuse-form.css', array(), $ver = false, $media = 'all');
      wp_enqueue_style('reuse-form');
      $reuse_form_scripts   = new WWCB_Reuse_Form;
      $webpack_public_path  = get_option('webpack_public_path_url', true);
      $reuse_form_scripts->load($webpack_public_path);
        
    }
  }
}

new WWCB_Frontend_Scripts();
