<?php
/**
 * Installation related functions and actions.
 *
 * @author   redqteam
 * @category Admin
 * @package  Wishlists & Collections/Classes
 * @version  1.0.1
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * WWCB_Install Class.
 */
class WWCB_Install {
    /**
     * Hook in tabs.
     */
    public static function init() {
        
        // Setup webpack path for reuse form
        $webpack_public_path = get_option('webpack_public_path_url', true);
        if($webpack_public_path == '' || $webpack_public_path == '1'){
          update_option('webpack_public_path_url', WWCB_JS_REUSE_FORM);
        }


        $wwc_admin_settings = get_option('wwc_admin_settings', true);

        if( $wwc_admin_settings['enable_collection'] !== 'no' ) {
            add_action( 'init', array( __CLASS__, 'view_collection_endpoints' ) );

            // add_action( 'init', array( __CLASS__, 'flush_rewrite_rules' ) );

            add_filter( 'query_vars', array( __CLASS__, 'view_collection_query_vars') );
          
            add_filter( 'woocommerce_account_menu_items', array( __CLASS__, 'view_collection_my_account_menu_items'), 10, 1 );
            add_action( 'woocommerce_account_wwc-collection_endpoint', array( __CLASS__, 'view_collection_endpoint_content' ) );
            add_action( 'woocommerce_account_wwc-private-collection_endpoint', array( __CLASS__, 'view_private_collection_endpoint_content' ) );
            add_action( 'woocommerce_account_wwc-shared-collection_endpoint', array( __CLASS__, 'view_shared_collection_endpoint_content' ) );
            add_action( 'woocommerce_account_wwc-shared-with-me_endpoint', array( __CLASS__, 'view_shared_with_me_endpoint_content' ) );
            add_action( 'woocommerce_account_wwc-shared-with-us_endpoint', array( __CLASS__, 'view_shared_with_us_endpoint_content' ) );
        }

        // add_action( 'woocommerce_account_page_endpoint', array( __CLASS__, 'view_collection_endpoint_content' ) );
    }

    /**
     * Install WC.
     */
    public static function install() {

        WWCB_Install::view_collection_endpoints();
        // WWCB_Install::view_collection_query_vars();

        // Register post types
        Redq_WWC_Post_Type::register_post_types();

        // Flush rules after install
        flush_rewrite_rules();
        WWCB_Install::flush_rewrite_rules();

        // Trigger action
        do_action( 'redq_wwc_installed' );
    }

    public static function flush_rewrite_rules() {
        global $wp_rewrite;

        $wp_rewrite->flush_rules();
    }

    /**
     * Check WooCommerce version and run the updater is required.
     *
     * This check is done on all requests and runs if he versions do not match.
     */
    public static function check_version() {
        if ( ! defined( 'IFRAME_REQUEST' ) && get_option( 'wishlist_collection_version' ) !== WWCB()->version ) {
            self::install();
            do_action( 'wishlist_collection_updated' );
        }
    }

    public static function view_collection_endpoints() {
      
      add_rewrite_endpoint( 'wwc-collection', EP_ROOT | EP_PAGES );
      add_rewrite_endpoint( 'wwc-private-collection', EP_ROOT | EP_PAGES );
      add_rewrite_endpoint( 'wwc-shared-collection', EP_ROOT | EP_PAGES );
      add_rewrite_endpoint( 'wwc-shared-with-me', EP_ROOT | EP_PAGES );
      // add_rewrite_endpoint( 'view-quote', EP_ALL );
    }

    public static function view_collection_query_vars( $vars ) {
        // _log($vars);
        $vars[] = 'wwc-collection';
        $vars[] = 'wwc-private-collection';
        $vars[] = 'wwc-shared-collection';
        $vars[] = 'wwc-shared-with-me';
        // $vars[] = 'page';

        return $vars;
    }

    public static function view_collection_my_account_menu_items( $items ) {
        
        $new_items = array();
        foreach ($items as $key => $value) {
            if( $key === 'customer-logout') {
                $new_items['wwc-collection'] = __( 'View Collection', 'woocommerce-wishlist-collection' );
                // $new_items['wwc-private-collection'] = __( 'Private Collection', 'woocommerce-wishlist-collection' );
            }

            $new_items[$key] = $value;
            
        }

        return $new_items;
    }

    public static function view_collection_endpoint_content( $page ) {
        wc_get_template( 'myaccount/view-collection.php', array( 'page'  => $page ), $template_path = '', WWCB_TEMPLATE_PATH);
    }

    public static function view_private_collection_endpoint_content( $page ) {
        wc_get_template( 'myaccount/view-private-collection.php', array( 'page'  => $page ), $template_path = '', WWCB_TEMPLATE_PATH);
    }

    public static function view_shared_collection_endpoint_content( $page ) {
        wc_get_template( 'myaccount/view-shared-collection.php', array( 'page'  => $page ), $template_path = '', WWCB_TEMPLATE_PATH);
    }

    public static function view_shared_with_me_endpoint_content( $page ) {
        wc_get_template( 'myaccount/view-shared-with-me.php', array( 'page'  => $page ), $template_path = '', WWCB_TEMPLATE_PATH);
    }
}

WWCB_Install::init();
