<?php

/**
 * Class RedqWC_My_Wishlits_Query
 *
 * @author      redqteam
 * @category    Admin
 * @package     WWCB\Includes
 * @version     2.0.3
 * @since       1.0.0
 */
class WWCB_My_Wishlits_Query {
  /**
   * __construct
   * Class constructor function contains my wishlists shortcode WP_Query $args via add_filter hook.
   *
   * @version 1.0.0
   * @since 1.0.0
   * @return null
   */
  public function __construct() {

    /**
     * @hook add_filter
     */
    add_filter( 'redq_wwc_my_wishlists_main_query_args', array( $this, 'redq_wwc_my_wishlists_main_query_args' ), 10, 2 );

  }

  /**
   * MY Wishlists Shortcode main WP_Query $args
   * @return (array) $args
   */
  /**
   * redq_wwc_my_wishlists_main_query_args
   * MY Wishlists Shortcode main WP_Query $args via add_filter callback.
   *
   * @param $args, $posts_per_page
   * @version 1.0.0
   * @since 1.0.0
   * @return (array) $args
   */
  function redq_wwc_my_wishlists_main_query_args( $args, $posts_per_page ) {
    $user_id = get_current_user_id(); // current user
    $meta_posts = get_user_option( "_wishlisted_product", $user_id  ); // post ids from user meta

    $post_type = $_GET['type'];

    $posts_in = array();
    if( empty( $meta_posts ) ) {
      return array();
    }
    foreach ($meta_posts[$post_type] as $post) {
      $posts_in[] = $post;
    }

    $paged = ( get_query_var('paged') ) ? get_query_var('paged') : 1;
    // $current_theme = wp_get_theme();
    // $current_theme_name = $current_theme->get( 'Name' );

    $orderby_key = apply_filters('redq_wwc_query_var_orderby_key', 'orderby' );
    $order_key = apply_filters('redq_wwc_query_var_order_key', '' );
    
    $orderby = ( isset( $_GET[$orderby_key] ) && $_GET[$orderby_key] ) ? $_GET[$orderby_key] : 'title menu_order';
    $order = ( isset( $_GET[$order_key] ) && $_GET[$order_key] ) ? $_GET[$order_key] : '';

    $meta_query = array();
    $meta_key = null;

    switch ( $orderby ) {
      case 'menu_order':
        $orderby = 'title menu_order';
        $order = ($order) ? $order : 'desc';
      break;

      case 'popularity':
        $orderby = 'meta_value_num';
        $meta_key = 'total_sales';
        $order = ($order) ? $order : 'desc';
      break;

      case 'rating':
        $orderby = 'meta_value_num';
        $meta_key = '_wc_average_rating';
        $order = ($order) ? $order : 'desc';

        $meta_query = array(
          'key'           => '_wc_average_rating',
          'value'         => 0,
          'compare'       => '>=',
          'type'          => 'DECIMAL',
          'rating_filter' => true,
        );
      break;

      case 'date':
        $order = ($order) ? $order : 'asc';
      break;

      case 'price':
        $orderby = 'meta_value_num';
        $meta_key = '_price';
        $order = ($order) ? $order : 'asc';
      break;

      case 'price-desc':
        $order = 'desc';
        $orderby = 'meta_value_num';
        $meta_key = '_price';
      break;

      default:
        $orderby = 'title menu_order';
        $order = ($order) ? $order : 'asc';
      break;
    }

    $args = array(
      'post_type'       => 'product',
      'post__in'        => $posts_in,
      'posts_per_page'  => apply_filters( 'redq_wwc_query_posts_per_page', $posts_per_page ),
      'paged'           => $paged,
      'orderby'         => $orderby,
      'order'           => $order,
      'meta_key'        => $meta_key,
      'meta_query'      => $meta_query,
    );
    
    return $args;
  }
}

new WWCB_My_Wishlits_Query();
