<?php

/**
 * Class Redq_WWC_Theme_Support
 *
 * @author      redqteam
 * @category    Admin
 * @package     Wishlist\Includes
 * @version     1.0.1
 * @since       1.0.0
 */
class Redq_WWC_Theme_Support {
  
  public $current_theme;

  /**
   * __construct
   * Class constructor theme support compatability via add_filter hook.
   *
   * @version 1.0.0
   * @since 1.0.0
   * @return null
   */
  public function __construct() {

    /**
     * @hook add_filter
     */
    add_filter( 'body_class', array( $this, 'wp_body_classes' ) );

    // avada theme hack
    add_filter( 'redq_wwc_query_posts_per_page', array( $this, 'redq_wwc_query_posts_per_page' ) );
    add_filter( 'redq_wwc_query_var_order_key', array( $this, 'redq_wwc_query_var_order_key' ), 10 );
    add_filter( 'redq_wwc_query_var_orderby_key', array( $this, 'redq_wwc_query_var_orderby_key' ), 10 );

    /**
     * @hook add_action
     */
    add_action( 'woocommerce_after_shop_loop_item', array( $this, 'redq_wwc_woocommerce_template_loop_add_to_cart' ), 15 );
    // add_action( 'woocommerce_single_product_summary', array( $this, 'redq_wwc_woocommerce_single_product_summary' ), 35 );
    add_action( 'woocommerce_after_add_to_cart_button', array( $this, 'redq_wwc_woocommerce_single_product_summary' ), 35 );


    // $active_theme = wp_get_theme();
    // $this->current_theme = $active_theme->get( 'Name' );

    // if( $this->current_theme === 'Avada' ) {
    //   add_action( 'pre_get_posts', array( $this, 'wwc_avada_woocommerce_ordering' ), 5 );
    // }

  }
  public function redq_wwc_woocommerce_single_product_summary( $args = array() ) {
    echo "<div class='wwc-shortcode-button'>";
    $wwc_admin_settings = get_option('wwc_admin_settings', true);
    if( $wwc_admin_settings['enable_wishlist'] !== 'no' ) {
      echo do_shortcode('[wwc_wishlist_button]');
    }
    if( $wwc_admin_settings['enable_collection'] !== 'no' ) {
      echo do_shortcode('[wwc_collection_button]');
    }
    
    echo "</div>";
  }

  function wwc_avada_woocommerce_ordering( $query ) {
    $queried_object = $query->queried_object;
    $query_vars = $query->query_vars;
    if ( ( is_single() && isset( $query_vars['post_type'] ) && $query_vars['post_type'] === 'wwc_collection' ) || ( isset( $queried_object->post_content ) && strpos($queried_object->post_content, '[wwc_my_wishlists') !== false ) ) {
        if ( Avada()->settings->get( 'woocommerce_avada_ordering' ) ) {
          remove_action( 'woocommerce_before_shop_loop', 'woocommerce_catalog_ordering', 30 );
          add_action( 'woocommerce_before_shop_loop', array( new Avada_Woocommerce(), 'catalog_ordering' ), 30 );

          add_action( 'woocommerce_get_catalog_ordering_args', array( $this, 'get_catalog_ordering_args' ), 20 );
        }
    }
  }

  public function redq_wwc_woocommerce_template_loop_add_to_cart( $args = array() ) {
    $wwc_admin_settings = get_option('wwc_admin_settings', true);
    if( $wwc_admin_settings['enable_wishlist'] !== 'no' ) {
      echo do_shortcode('[wwc_wishlist_button]');  
    }
    
    if( $wwc_admin_settings['enable_collection'] !== 'no' ) {
      echo do_shortcode('[wwc_collection_button]');
    }
  }
  
  /**
   * Add WooCommerce & WooCommerce Page class to the body tag
   * This will check if the page contains [redq_wwc_my_wishlists] shortcode
   */
  
  // previous function

  // function wp_body_classes( $classes ) {
  //   global $post;
  //   if( is_page() && strpos($post->post_content, '[wwc_my_wishlists') !== false) {
  //     $classes[] = 'woocommerce';
  //     $classes[] = 'woocommerce-page';
  //   }
  //   if( ( is_single() || is_archive() ) && $post->post_type === 'wwc_collection') {
  //     $classes[] = 'woocommerce';
  //     $classes[] = 'woocommerce-page';
  //   }
  //   return $classes;
  // }

  function wp_body_classes( $classes ) {
    global $post;
    if ( class_exists('WooCommerce')) { 
	    if ( !array_key_exists('woocommerce', $classes) ) {
		    $classes = array_merge( $classes, array( 'woocommerce' ) );
		    $classes = array_merge( $classes, array( 'woocommerce-page' ) );
		    return $classes;
	  	} 
	  }	else {
  		return $classes;
  	}
  }

  function redq_wwc_query_posts_per_page( $count ) {

    $new_count = ( isset( $_GET['product_count'] ) && $_GET['product_count'] ) ? $_GET['product_count'] : $count;
    
    return $new_count;
  }

  function redq_wwc_query_var_order_key( $order ) {
    
    switch ( $this->current_theme ) {
      case 'Avada':
        return 'product_order';
      break;
      
      default:
        return '';
      break;
    }
    
  }

  function redq_wwc_query_var_orderby_key( $orderby ) {

    switch ( $this->current_theme ) {
      case 'Avada':
        return 'product_orderby';
      break;
      
      default:
        return 'orderby';
      break;
    }
  }
}

new Redq_WWC_Theme_Support();
