<?php

/**
 * Wishlist & Collection  WWCB_Wishlists
 *
 * Product wishlists class. Use the [wishlist_button] shortcode inside the loop that will do the rest.
 * This post like also get anonymous like from any user who is not logged in to the site.
 * Anonymous post contains user's IP address.
 *
 * @class       WWCB_Wishlists
 * @version     2.0.4
 * @package     Wishlists & Collections/Includes
 * @since       1.0.0
 * @category    Class
 * @author      redqteam
 */

class WWCB_Wishlists {

  /**
   * __construct
   * Class constructor function contains product wishlist ajax and the shortcode.
   *
   * @version 1.0.0
   * @since 1.0.0
   * @return null
   */
  public function __construct() {
    // add_action( 'wp_ajax_nopriv_add_to_wishlist', array( $this, 'add_to_wishlist' ) );
    add_action( 'wp_ajax_add_to_wishlist', array( $this, 'add_to_wishlist' ) );

    add_shortcode( 'wwc_wishlist_button', array( $this, 'wishlist_button_shortcode' ) );

  }


  /**
   * add_to_wishlist
   * The main function for adding the post like.
   *
   * @version 1.0.0
   * @since 1.0.0
   * @return HTML
   */
  public function add_to_wishlist() {

    $nonce = $_POST['nonce'];
      if ( ! wp_verify_nonce( $nonce, 'wishlists' ) )
          die ( 'Nope!' );

    if ( isset( $_POST['add_to_wishlist'] ) ) {

      $product_id = $_POST['product_id']; // post id
      $post_type  = $_POST['post_type']; // post type

      if ( function_exists ( 'wp_cache_post_change' ) ) { // invalidate WP Super Cache if exists
        $GLOBALS["super_cache_enabled"] = 1;
        wp_cache_post_change( $product_id );
      }

      if ( is_user_logged_in() ) { // user is logged in
        $user_id = get_current_user_id(); // current user
        $meta_POSTS = get_user_option( "_wishlisted_product", $user_id  ); // post ids from user meta
        $meta_USERS = get_post_meta( $product_id, "_user_wished" ); // user ids from post meta
        $liked_POSTS = NULL; // setup array variable
        $liked_USERS = NULL; // setup array variable
        $post_author = get_post_field( 'post_author', $product_id );

        if ( count( $meta_POSTS ) != 0 ) { // meta exists, set up values
          $liked_POSTS = $meta_POSTS;
        }

        if ( !is_array( $liked_POSTS ) ) // make array just in case
          $liked_POSTS = array();

        if ( count( $meta_USERS ) != 0 ) { // meta exists, set up values
          $liked_USERS = $meta_USERS[0];
        }

        if ( !is_array( $liked_USERS ) ) // make array just in case
          $liked_USERS = array();



        $liked_USERS['user-'.$user_id]  = $user_id; // add user id to post meta array

        if ( !$this->already_added( $product_id ) ) { // like the post

          if( empty( $liked_POSTS ) ) {
            $liked_POSTS[$post_type][]            = $product_id; // Add post id to user meta array
          } else {
            if( isset( $liked_POSTS[$post_type] ) ) {
              if( !in_array( $product_id, $liked_POSTS[$post_type] ) ) {
                $liked_POSTS[$post_type][]      = $product_id; // Add post id to user meta array
              }
            } else {
              $liked_POSTS[$post_type][]      = $product_id; // Add post id to user meta array
            }
          }

          update_post_meta( $product_id, "_user_wished", $liked_USERS ); // Add user ID to post meta

          update_user_option( $user_id, "_wishlisted_product", $liked_POSTS ); // Add post ID to user meta

          echo 'added';

        } else { // unlike the post

          foreach ($liked_POSTS as $key => $value) {
            if( $key == $post_type ) {
              if( in_array( $product_id, $value) ) {
                $pid_key = array_search( $product_id, $value ); // find the key
                unset( $liked_POSTS[$key][$pid_key] );
              }
            }
          }

          $uid_key = array_search( $user_id, $liked_USERS ); // find the key

          unset( $liked_USERS[$uid_key] ); // remove from array

          update_post_meta( $product_id, "_user_wished", $liked_USERS ); // Remove user ID from post meta

          update_user_option( $user_id, "_wishlisted_product", $liked_POSTS ); // Remove post ID from user meta

          echo 'removed';

        }

      }
    }

    exit;
  }

  /**
   * Check already added or not?
   *
   * @param $product_id
   * @version 2.0.2
   * @since 1.0.0
   * @return bool
   */
  public function already_added( $product_id ) { // test if user liked before
    if ( is_user_logged_in() ) { // user is logged in
      $user_id = get_current_user_id(); // current user
      $meta_USERS = get_post_meta( $product_id, "_user_wished" ); // user ids from post meta
      $liked_USERS = ""; // set up array variable

      if ( count( $meta_USERS ) != 0 ) { // meta exists, set up values
        $liked_USERS = $meta_USERS[0];
      }

      if( !is_array( $liked_USERS ) ) // make array just in case
        $liked_USERS = array();

      if ( in_array( $user_id, $liked_USERS ) ) { // True if User ID in array
        return true;
      }
      return false;

    }

  }

  /**
   * Generate the shortcode HTML link
   *
   * @param $product_id
   * @version 2.0.4
   * @since 1.0.0
   * @return HTML
   */
  public function get_product_add_to_wishlist_link( $product_id, $icon, $icon_alt, $text, $preview, $parent_class, $already_added, $post_type ) {
    if( !empty( $already_added ) ) {
    	if( $already_added == 'true' ) {
    		$class = ' wished';
	      $title = __( 'Remove from wishlist', 'wwcb' );
	      $heart = '<i class="redq-wwc-icon-wishlist '.$icon.'"></i>';
    	} else {
    		$class = '';
	      $title = __( 'Add to wishlist', 'wwcb' );
	      $heart = '<i class="redq-wwc-icon-not-wishlist '.$icon_alt.'"></i>';
    	}
    } else {
    	if ( $this->already_added( $product_id ) ) {
	      $class = ' wished';
	      $title = __( 'Remove from wishlist', 'wwcb' );
	      $heart = '<i class="redq-wwc-icon-wishlist '.$icon.'"></i>';
	    } else {
	      $class = '';
	      $title = __( 'Add to wishlist', 'wwcb' );
	      $heart = '<i class="redq-wwc-icon-not-wishlist '.$icon_alt.'"></i>';
	    }
    }

    $class .= ' ' . $parent_class;

    if( empty( $post_type ) ) {
    	global $post;
    	$post_type = $post->post_type;
    }

    $output = '<a href="#" class="redq-wwc-add-wishlist '.trim($class).'" data-product_id="'.$product_id.'" title="'.$title.'" data-post_type="'.$post_type.'" data-icon="'.$icon.'" data-icon_alt="'.$icon_alt.'" data-text="'.$text.'" data-preview="'.$preview.'">';
      switch( $preview ) {
        case "text":
          $output .= esc_attr($text);
          break;
        case "icon":
          $output .= $heart;
          break;
        case "text_icon":
          $output .= esc_attr($text) . ' ' . $heart;
          break;
        case "icon_text":
          $output .= $heart . ' ' . esc_attr($text);
          break;
        default:
        $output .= esc_attr($text);
        break;
      }
    $output .= '</a>';
    return $output;
  }

  /**
   * Add a shortcode to your product instead
   * type [wishlist_button] in your product to output the button
   * @version 2.0.4
   * @since 1.0.0
   * @return HTML
   */
  function wishlist_button_shortcode( $atts, $content = null ) {
    extract( shortcode_atts( array(
      'icon'          => 'ion-android-favorite',
      'icon_alt'      => 'ion-android-favorite-outline',
      'text'          => __('Favourite', 'wwcb'),
      'preview'       => 'icon', // text, icon, text_icon, icon_text
      'parent_class'  => '',
      'post_id'       => null,
      'already_added' => '',
      'post_type' 		=> '',
    ), $atts) );

    wp_localize_script( 'wwc-wishlist', 'WISHLIST_ICON', array(
      'icon'    => $icon,
      'iconAlt' => $icon_alt,
      'text'    => $text,
      'preview' => $preview,
    ));

    if( $post_id == null ) {
      $post_id = get_the_id();
    }

    return $this->get_product_add_to_wishlist_link(
      $post_id,
      $icon,
      $icon_alt,
      $text,
      $preview,
      $parent_class,
      $already_added,
      $post_type
    );
  }

}

new WWCB_Wishlists();
