<?php

/**
 * Get template part (for templates like the shop-loop).
 *
 * @access public
 * @param mixed $slug
 * @param string $name (default: '')
 */
function redq_wwc_get_template_part( $slug, $name = '' ) {
    $template = '';

    // Look in yourtheme/slug-name.php and yourtheme/userplace/slug-name.php
    if ( $name && ! WWCB_TEMPLATE_DEBUG_MODE ) {
        $template = locate_template( array( "{$slug}-{$name}.php", WWCB()->template_path() . "{$slug}-{$name}.php" ) );
    }

    // Get default slug-name.php
    if ( ! $template && $name && file_exists( WWCB()->plugin_path() . "/templates/{$slug}-{$name}.php" ) ) {
        $template = WWCB()->plugin_path() . "/templates/{$slug}-{$name}.php";
    }

    // If template file doesn't exist, look in yourtheme/slug.php and yourtheme/userplace/slug.php
    if ( ! $template && ! WWCB_TEMPLATE_DEBUG_MODE ) {
        $template = locate_template( array( "{$slug}.php", WWCB()->template_path() . "{$slug}.php" ) );
    }

    // Allow 3rd party plugin filter template file from their plugin
    if ( ( ! $template && WWCB_TEMPLATE_DEBUG_MODE ) || $template ) {
        $template = apply_filters( 'redq_wwc_get_template_part', $template, $slug, $name );
    }

    if ( $template ) {
        load_template( $template, false );
    }
}

/**
 * Get other templates
 *
 * @access public
 * @param string $template_name
 * @param array $args (default: array())
 * @param string $template_path (default: '')
 * @param string $default_path (default: '')
 */
function redq_wwc_get_template( $template_name, $args = array(), $template_path = '', $default_path = '' ) {
    if ( $args && is_array( $args ) ) {
        extract( $args );
    }

    $located = red_wwc_locate_template( $template_name, $template_path, $default_path );

    if ( ! file_exists( $located ) ) {
        _doing_it_wrong( __FUNCTION__, sprintf( '<code>%s</code> does not exist.', $located ), '2.1' );
        return;
    }

    // Allow 3rd party plugin filter template file from their plugin
    $located = apply_filters( 'redq_wwc_get_template', $located, $template_name, $args, $template_path, $default_path );

    do_action( 'redq_wwc_before_template_part', $template_name, $template_path, $located, $args );

    include( $located );

    do_action( 'redq_wwc_after_template_part', $template_name, $template_path, $located, $args );
}

/**
 * Locate a template and return the path for inclusion.
 *
 * This is the load order:
 *
 *      yourtheme       /   $template_path  /   $template_name
 *      yourtheme       /   $template_name
 *      $default_path   /   $template_name
 *
 * @access public
 * @param string $template_name
 * @param string $template_path (default: '')
 * @param string $default_path (default: '')
 * @return string
 */
function red_wwc_locate_template( $template_name, $template_path = '', $default_path = '' ) {
    if ( ! $template_path ) {
        $template_path = WWCB()->template_path();
    }

    if ( ! $default_path ) {
        $default_path = WWCB()->plugin_path() . '/templates/';
    }

    // Look within passed path within the theme - this is priority
    $template = locate_template(
        array(
            trailingslashit( $template_path ) . $template_name,
            $template_name
        )
    );

    // Get default template
    if ( ! $template || WWCB_TEMPLATE_DEBUG_MODE ) {
        $template = $default_path . $template_name;
    }

    // Return what we found
    return apply_filters( 'redq_wwc_locate_template', $template, $template_name, $template_path );
}


/**
 * Enables template debug mode
 */
function rwishlist_template_debug_mode() {
    if ( ! defined( 'WWCB_TEMPLATE_DEBUG_MODE' ) ) {
        $status_options = get_option( 'redq_wwc_status_options', array() );
        if ( ! empty( $status_options['template_debug_mode'] ) && current_user_can( 'manage_options' ) ) {
            define( 'WWCB_TEMPLATE_DEBUG_MODE', true );
        } else {
            define( 'WWCB_TEMPLATE_DEBUG_MODE', false );
        }
    }
}
add_action( 'after_setup_theme', 'rwishlist_template_debug_mode', 20 );


add_action( 'template_redirect', function() {
    if ( is_singular( 'collection' ) ) {
        global $wp_query;
        $page = ( int ) $wp_query->get( 'page' );
        if ( $page > 1 ) {
            // convert 'page' to 'paged'
            $query->set( 'page', 1 );
            $query->set( 'paged', $page );
        }
        // prevent redirect
        remove_action( 'template_redirect', 'redirect_canonical' );
    }
}, 0 ); // on priority 0 to remove 'redirect_canonical' added with priority 10

// function redq_wwc_get_user_name_by_id( $user_id ){

//     $user = get_user_by( 'id', $user_id );

//     if( isset($user) && !empty($user)){
//         $fullname = $user->first_name.' '.$user->last_name;
//     }else{
//         $fullname = '';
//     }

//     return $fullname;
// }

function redq_wwc_get_all_user_info() {
    if( is_singular( 'wwc_collection' ) && get_post_status ( get_the_ID() ) == 'shared' ) {
        $all_users = get_users();
        $publish = array();
        foreach( $all_users as $user ) {

            if( get_current_user_id() != $user->ID ){

                $publish[] = array(
                    'ID' => $user->ID ,
                    // 'name' => redq_wwc_get_user_name_by_id( $user->ID ),
                    'username' => $user->data->user_login,
                    'email' => $user->data->user_email,
                );

            }

        }

        if( !empty($publish) ){
            return $publish;
        }else{
            return array();
        }
    }
}

/**
 * Collction Archive Page navigation template.
 */
function redq_wwc_archive_collection_nav_menu() {
    redq_wwc_get_template( 'menu/archive-menu.php' );
}

/**
 * Collction My Account Page navigation template.
 */
function redq_wwc_my_account_collection_nav_menu( $url_endpoint ) {
    redq_wwc_get_template( 'menu/my-account-menu.php', array( 'url_endpoint' => $url_endpoint ) );
}
